AppLogs class

A class for logging application errors.

Constructors

AppLogs()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

logError({required String fileName, required String error, StackTrace? stackTrace, String? text}) → void
Logs an error message with optional additional information.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

showLogs bool
A static variable to control whether logs should be displayed.
getter/setter pair