ReturnModel class

A model class that represents the details of a file.

Constructors

ReturnModel({String? filePath, String? fileName, String? fileExtension, double? size})
Creates an instance of ReturnModel.
ReturnModel.fromJson(Map<String, dynamic> json)
Creates an instance of ReturnModel from a JSON object.

Properties

fileExtension String?
The extension of the file.
getter/setter pair
fileName String?
The name of the file.
getter/setter pair
filePath String?
The path of the file.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double?
The size of the file in bytes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts an instance of ReturnModel to a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited